function AndrzejakEspinosoChaos2023Example(Example)
% This source code allows you to reproduce the simulations presented in the
% paper:
%
% Andrzejak RG, Espinoso A
% Chimera states in multiplex networks: Chameleon-like across-layer synchronization.
% Chaos 33, 053112 (2023), https://doi.org/10.1063/5.0146550
%
% Please give a reference to this manuscript if you use this source code in
% your publications.
%
% Prior to using the code and interpreting your results, please read the following remarks.
%
% Inputs 1-8 correspond to the settings considered in the eight rows of
% table 1 in the paper. However, they require a lot of memory and computation time.
% Note, furthermore, that you will get somewhat different values for each
% run, and that these values will in general be different from the
% values in table 1 since the exact values depend on the initial conditions
% used to start the network.
% Input 9 corresponds to the setting of Figure 5f of the paper.
% Input 11-19 are the same as 1-9, respectively, but for a smaller 
% total number of samples. These results will be different. Like commented
% in the paper, metrics such as phase locking values depend on the
% observation time.
%
% Before publishing the source code, we have simplified it and reduced
% it to the essentials to allow for a better understanding. We furthermore
% matched variable names in the source code to those in the manuscript. We
% are confident that, also with these simplifications and changes, the
% source code contains no bugs. However, if you encounter problems or bugs,
% please contact us.
%
% Depending on the network size and number of total samples, the code 
% can take large amounts of memory and computation time. There are certain
% tricks to reduce both, which are not implemented here. Feel free to
% contact us in case you want to know about them.
%
% The variables TS,EO,CO,T are in units of samples. To express them in
% time units, they need to be divided by Deltat. 
        
        
switch Example
    case 1
        N=50;
        epsilon=0;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
   case 2
        N=50;
        epsilon=0.01;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 3
        N=50;
        epsilon=0.03;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 4
        N=50;
        epsilon=0.24;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 5
        N=50;
        epsilon=0.26;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
   case 6
        N=50;
        epsilon=0.31;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 7
        N=50;
        epsilon=0.37;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
     case 8
        N=50;
        epsilon=0.46;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 9
        N=50;
        epsilon=0.3;
        alphaX=1.485;
        alphaY=1.485;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=2000000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
     case 11
        N=50;
        epsilon=0;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
   case 12
        N=50;
        epsilon=0.01;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 13
        N=50;
        epsilon=0.03;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 14
        N=50;
        epsilon=0.24;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 15
        N=50;
        epsilon=0.26;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
   case 16
        N=50;
        epsilon=0.31;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 17
        N=50;
        epsilon=0.37;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
     case 18
        N=50;
        epsilon=0.46;
        alphaX=1.485;
        alphaY=1.513;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
    case 19
        N=50;
        epsilon=0.3;
        alphaX=1.485;
        alphaY=1.485;
        nuX=0;
        nuY=0.2;
        bX=18;
        bY=18;
        Deltat=0.05;
        TS=600000;
        EO=200000;        
        CO=20000;        
        T=2000;
        verbose=1;
end

[CoO, allphi, ResDeltaC, ResXi, ResS, ResK, ResLS, ResLW, ResDPhi, ResG] = ...
    AndrzejakEspinosoChaos2023(N,epsilon,alphaX,alphaY,nuX,nuY,bX,bY,TS,CO,EO,T,Deltat,verbose);

allphi = allphi(end-40000+1:end,:); %Only taking the last 2000 time units
fname=sprintf('AndrzejakEspinosoChaos2023SettingNo%iResults',Example);
save(fname);
